/* ***** BEGIN LICENSE BLOCK ***** 
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Tabbrowser Extensions.
 *
 * The Initial Developer of the Original Code is SHIMODA Hiroshi.
 * Portions created by the Initial Developer are Copyright (C) 2002-2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): SHIMODA Hiroshi <piro@p.club.ne.jp>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

function initExtraDialog()
{
	var TS = TabbrowserService;


	// status section

	initCheckbox('Locked', 'locked' in gInfo && gInfo.locked);
	initCheckbox('ReferrerBlocked', 'referrerBlocked' in gInfo && gInfo.referrerBlocked);
	initCheckbox('AutoReload', ('autoreloadInterval' in gInfo && gInfo.autoreloadInterval ? true : false ));

	document.getElementById('AutoReloadInterval').value = 'autoreloadInterval' in gInfo ? Math.max(Number(gInfo.autoreloadInterval)/1000, 0) : 0 ;

	initCheckbox('AllowPlugins', 'allowPlugins' in gInfo && gInfo.allowPlugins);
	initCheckbox('AllowJavascript', 'allowJavascript' in gInfo && gInfo.allowJavascript);
	initCheckbox('AllowMetaRedirects', 'allowMetaRedirects' in gInfo && gInfo.allowMetaRedirects);
	initCheckbox('AllowSubframes', 'allowSubframes' in gInfo && gInfo.allowSubframes);
	initCheckbox('AllowImages', 'allowImages' in gInfo && gInfo.allowImages);


	if (!TS.shouldSaveBookmarksStatus)
		showHideItem('status-groupbox', false);

	if (!TS.shouldSaveBookmarksStatus ||
		!TS.shouldSaveBookmarksPermissions)
		showHideItem('allow-groupbox', false);

	if (!TS.shouldSaveBookmarksStatus &&
		!TS.shouldSaveBookmarksPermissions) {
		showHideItem('description-disabled', true);
	}

	controlLinkedItems(document.getElementById('AutoReload'));


	// referrer and favicon
	document.getElementById('IconURI').value = getIcon();
	document.getElementById('ReferrerURI').value = 'referrerURI' in gInfo ? (gInfo.referrerURI || '') : '' ;



	// others
	var checkbox = document.getElementById('UseFixedLabel');
	if (TS.getPref('browser.tabs.extensions.bookmarks.use_fixed_label')) {
		checkbox.setAttribute('disabled', true);
	}
	else {
		checkbox.removeAttribute('disabled');
		initCheckbox('UseFixedLabel', 'useFixedLabel' in gInfo && gInfo.useFixedLabel);
	}

	var box = document.getElementById('TextZoom-box');
	var i;
	if (!TS.getPref('browser.tabs.extensions.bookmarks.save_textZoom')) {
		for (i = 0; i < box.childNodes.length; i++)
			box.childNodes[i].setAttribute('disabled', true);
	}
	else {
		for (i = 0; i < box.childNodes.length; i++)
			box.childNodes[i].removeAttribute('disabled');

		document.getElementById('TextZoom').value = 'textZoom' in gInfo ? Math.min(Math.max(Number(gInfo.textZoom), TabbrowserService.ZOOM_MIN), TabbrowserService.ZOOM_MAX) : 100 ;
	}
}

function initCheckbox(aID, aFlag)
{
	var node = document.getElementById(aID);
	if (node) node.checked = Boolean(aFlag);
}

function showHideItem(aID, aFlag)
{
	var node = document.getElementById(aID);
	if (node) node.hidden = !aFlag;
}


function chooseIcon()
{
	var icon = window.parent.TabbrowserService.chooseIcon();
	if (icon)
		document.getElementById('IconURI').value = icon;
}


function onAccept()
{
	window.opener.document.getElementById('description').value = document.getElementById('description').value;
	window.opener.document.getElementById('IconURI').value = document.getElementById('IconURI').value;
	window.opener.gInfo = window.gInfo;
	window.close();
}



function controlLinkedItems(elem)
{
	var target = elem.getAttribute('linked').split(/ +/);
	var item;

	var disabled = (elem.localName == 'textbox' ? (!elem.value || !Number(elem.value)) : !elem.checked );

	for (var i in target)
	{
		item = document.getElementById(target[i]);
		item.disabled = disabled;
	}
}


function updateDescription(aProperty, aValue)
{
	if (aProperty == 'autoreloadInterval')
		aValue = Math.max(Number(aValue)*1000, 0);

	gInfo[aProperty] = aValue;

	var desc = document.getElementById('description');
	desc.value = TabbrowserService.createNewBookmarkDescription(gBookmarkID, gInfo, desc.value);
}
