/* ***** BEGIN LICENSE BLOCK ***** 
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Tabbrowser Extensions.
 *
 * The Initial Developer of the Original Code is SHIMODA Hiroshi.
 * Portions created by the Initial Developer are Copyright (C) 2002-2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): SHIMODA Hiroshi <piro@p.club.ne.jp>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var gBookmarkID;
var gBookmarkURI;
var gBookmarkResource;
var gBookmarkURIResource;
var gInfo = {};

function getIcon()
{
	return TabbrowserService.getIconForBookmark(gBookmarkURI);
}

function setIcon()
{
	TabbrowserService.setIconForBookmark(gBookmarkURI);
}

function newCommit()
{
	var i;
	var TS = TabbrowserService;

	var allowProps = {
		// <property>      : <enabled by default>
		allowPlugins       : TS.getPref('browser.tabs.extensions.allowPlugins.enabled'),
		allowJavascript    : TS.getPref('browser.tabs.extensions.allowJavascript.enabled'),
		allowMetaRedirects : TS.getPref('browser.tabs.extensions.allowMetaRedirects.enabled'),
		allowSubframes     : TS.getPref('browser.tabs.extensions.allowSubframes.enabled'),
		allowImages        : TS.getPref('browser.tabs.extensions.allowImages.enabled')
	};
	for (i in allowProps)
		if (i in gInfo && gInfo[i] == allowProps[i])
			delete gInfo[i];



	var desc = document.getElementById('description');
	desc.value = TS.createNewBookmarkDescription(gBookmarkID, gInfo, desc.value);

	if (getIcon() != document.getElementById('IconURI').value) {
		try {
			var node = document.getElementById('IconURI');
			var testURI = TS.makeURIFromSpec(node.value);
			TS.iconData.setData(gBookmarkURI, 'IconURI', node.value || void(0));
		}
		catch(e) {
		}
		setIcon();
	}

	var retVal = __tabextensions__Commit();


	gInfo.uri = gBookmarkURI;

	var w = TS.browserWindows;
	var b;

	var j;
	var name = ('useFixedLabel' in gInfo && gInfo.useFixedLabel) ? TS.getNameForBookmark(gBookmarkID) : null ;
	for (i in w)
	{
		b = w[i].TabbrowserService.browser;
		for (j in b.mTabs)
			if (b.mTabs[j].mTabInfo.bookmarkID == gBookmarkID) {
				b.initTabWithTabInfo(b.mTabs[j], gInfo);
				if (name) b.setFixedLabelFor(b.mTabs[j], name, gBookmarkURI);
			}
	}

	return retVal;
}


window.addEventListener(
	'load',
	function()
	{
		var i;
		var TS = TabbrowserService;
		gBookmarkID = window.arguments[0];

		gBookmarkResource = TS.RDF.GetResource(gBookmarkID);

		gBookmarkURI = TS.BookmarksDS.GetTarget(gBookmarkResource, TS.kNC_URL, true);

		gBookmarkURI = gBookmarkURI ? gBookmarkURI.QueryInterface(Components.interfaces.nsIRDFLiteral).Value : null ;
		gBookmarkURIResource = gBookmarkURI ? TS.RDF.GetResource(gBookmarkURI) : null ;


		// don't initialize if this is a folder or a bookmarklet
		if (TS.isBookmarkFolder(gBookmarkResource) ||
			!gBookmarkURI ||
			gBookmarkURI.match(/^javascript:/i)) return;


		var desc = null;
		if (document.documentElement.id == 'bmExtraPropsWindow') {
			document.documentElement.setAttribute('title', document.documentElement.getAttribute('title').replace(/%s/gi, TS.getNameForBookmark(gBookmarkID)));
			desc = document.getElementById('description').value = window.opener.document.getElementById('description').value;
		}
		var info = TS.loadBookmarkStatus(gBookmarkID, null, desc);
		var props = [
				'useFixedLabel',
				'textZoom',
				'locked',
				'referrerBlocked',
				'autoreloadInterval',
				'allowPlugins',
				'allowJavascript',
				'allowMetaRedirects',
				'allowSubframes',
				'allowImages',
				'referrerURI'
			],
			allowProps = {
				// <property>      : <enabled by default>
				allowPlugins       : TS.getPref('browser.tabs.extensions.allowPlugins.enabled'),
				allowJavascript    : TS.getPref('browser.tabs.extensions.allowJavascript.enabled'),
				allowMetaRedirects : TS.getPref('browser.tabs.extensions.allowMetaRedirects.enabled'),
				allowSubframes     : TS.getPref('browser.tabs.extensions.allowSubframes.enabled'),
				allowImages        : TS.getPref('browser.tabs.extensions.allowImages.enabled')
			};

		for (i = 0; i < props.length; i++)
			if (props[i] in info)
				gInfo[props[i]] = info[props[i]];
			else if (props[i] in allowProps)
				gInfo[props[i]] = allowProps[props[i]];


		if (document.documentElement.id == 'bmExtraPropsWindow') {
			initExtraDialog();
		}
		else {
			window.__tabextensions__Commit = window.Commit;
			window.Commit = window.newCommit;

			var extra1 = document.documentElement.getButton('extra1');
			extra1.hidden = false;
			extra1.setAttribute('label', TS.strbundle.GetStringFromName('bookmarksProperty_extra1button'));
			extra1.setAttribute('oncommand', "window.openDialog('chrome://tabextensions/content/bookmarks/bm-props-extra.xul', '_blank', 'chrome,dialog,modal', gBookmarkID);");

			var iconURI = document.createElement('textbox');
			iconURI.setAttribute('id', 'IconURI');
			iconURI.setAttribute('hidden', true);
			iconURI.setAttribute('value', getIcon());
			document.documentElement.appendChild(iconURI);
		}

	},
	false
);
